@@ -5,7 +5,7 @@
 #' @keywords internal
 #' @import ggplot2
 #' @import dplyr
-#' @importFrom rlang quo_name quo_expr
+#' @importFrom rlang quo_name quo_squash
 #' @importFrom  plyr ddply
 #' 
 class_layer <- function(p){
@@ -30,7 +30,7 @@ class_layer <- function(p){
   plot_cl <- lapply(plot_aes$aes,function(x){
     
     TEMP <- p$data%>%
-      dplyr::mutate(.NEWVAR = !!rlang::quo_expr(p$mapping[[x]]))
+      dplyr::mutate(.NEWVAR = !!rlang::quo_squash(p$mapping[[x]]))
     
     class(TEMP[['.NEWVAR']])
 
@@ -59,9 +59,9 @@ class_layer <- function(p){
   }
   
   layer_aes <- lapply(p$layers,function(x){
-    
-    data.frame(VAR=sapply(x$mapping,quo_name),
-               aes=names(x$mapping),stringsAsFactors = FALSE)%>%
+    mappings <- x$mapping
+    data.frame(VAR = if(is.null(mappings)) character() else sapply(mappings, quo_name),
+               aes = if(is.null(mappings)) character() else names(x$mapping),stringsAsFactors = FALSE) %>%
       dplyr::filter(!is.null(!!rlang::sym('VAR')))
     
   })
